std.pipe.util


main-functionclj

(main-function func count)

creates a main function to be used for execution

creates a main function to be used for execution
raw docstring

select-filterclj

(select-filter selector id)

matches given a range of filters

matches given a range of filters
raw docstring

select-inputsclj

(select-inputs task lookup env selector)

selects inputs based on matches

selects inputs based on matches
raw docstring

task-inputsclj

(task-inputs task)
(task-inputs task input)
(task-inputs task input params)
(task-inputs task input params env)
(task-inputs task input params lookup env)

constructs inputs to the task given a set of parameters

constructs inputs to the task given a set of parameters
raw docstring

wrap-executeclj

(wrap-execute f task)

enables execution of task with transformations

enables execution of task with transformations
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries