(main-function func count)creates a main function to be used for execution
creates a main function to be used for execution
(select-filter selector id)matches given a range of filters
matches given a range of filters
(select-inputs task lookup env selector)selects inputs based on matches
selects inputs based on matches
(task-inputs task)(task-inputs task input)(task-inputs task input params)(task-inputs task input params env)(task-inputs task input params lookup env)constructs inputs to the task given a set of parameters
constructs inputs to the task given a set of parameters
(wrap-execute f task)enables execution of task with transformations
enables execution of task with transformations
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |